

var CircleStatus = null;

(function($){
  
  CircleStatus = CircleDiagram.extend({
      init: function(options) {
	  var self = this;
	  self.defaults = {
	      shadow: false,
	      root: true
	  };
	  self._opt = $.extend(self.defaults, options);
	  this._super(self._opt);
      },
      
      draw: function(start, end) {
	    var self = this;
	    self.endPos = end;
	    self.currPos = start;
	  
	    var canvas = self.opt.canvas;
	    var context = canvas.getContext('2d');
	    var x = self.opt.x;
	    var y = self.opt.y;
	    var radius = self.opt.radius;
	    var startAngle = start * Math.PI;
	    var endAngle = end * Math.PI;
	    var counterClockwise = false;

	    if(self.opt.shadow == true) {
		context.shadowOffsetX = 2;
		context.shadowOffsetY = 2;
		context.shadowBlur = 5;
		context.shadowColor = "#2f2f2f";
	    }else {
		context.shadowOffsetX = 0;
		context.shadowOffsetY = 0;
		context.shadowBlur = 0;
	    }

	    if(self.opt.root) {
		context.beginPath();
		context.arc(x, y, radius+22, startAngle, endAngle, counterClockwise);
		context.lineWidth = self.opt.width;
		// line color
		context.strokeStyle = '#7f7f7f';
		context.stroke();
		
		context.beginPath();
		context.arc(x, y, radius+10, startAngle, endAngle, counterClockwise);
		context.lineWidth = self.opt.width;
		// line color
		context.strokeStyle = '#404040';
		context.stroke();	
		
		context.beginPath();
		context.moveTo(x-radius , y);
		context.lineTo(x+radius, y);
		context.lineWidth = radius*2;
		context.stroke();
	    }

	    context.beginPath();
	    context.arc(x, y, radius, startAngle, endAngle, counterClockwise);
	    context.lineWidth = self.opt.width;

	    // line color
	    context.strokeStyle = self.opt.color;
	    context.stroke();	    
	    
	    context.beginPath();
	    context.shadowOffsetX = 0;
	    context.shadowOffsetY = 0;
	    context.shadowBlur = 0;    
	    
	    if(!self.opt.root) {
		context.fillStyle = self.opt.color;
		context.textAlign = 'center';
		if(self.opt.bigLabel) {
		    context.font = '15pt Calibri';
		    context.fillText(self.opt.proz+"%", x, y);
		}else {
		    context.font = '10pt Calibri';
		    context.fillText(self.opt.proz+"%", x, y+15);
		}
	    }
      
	    /*
	    if(self.opt.proz) {
		context.lineWidth = 1;	    
		var w = ( (end - (end-start)/2) * Math.PI);
		var _x_s = (Math.cos(w)*(radius-(self.opt.width/2) ));
		var _y_s = (Math.sin(w)*(radius-(self.opt.width/2) ));
		var _x = (Math.cos(w)*(radius+30));
		var _y = (Math.sin(w)*(radius+30));

		var _x_t = (Math.cos(w)*(radius+(self.opt.width*1.5) ));
		var _y_t = (Math.sin(w)*(radius+(self.opt.width*1.5) ));
		_x_t = _x_t -10;
		context.moveTo( x+_x_s , y+_y_s );
		
		if(self.opt.bigLabel) {	
		    context.lineTo(  x+_x , y+_y );
		    _x_t = _x_t +13;
		    _y_t = _y_t -10;
		    context.fillStyle = self.opt.color;
		    self.wrapText(context, "XXDas war deine Auswahl.", x+_x_t, y+_y_t+13, 120, 13);
		}else {
		    context.fillStyle = '#ffffff'; 
		}
		context.stroke();

		context.beginPath();
		context.font = '10pt Calibri';
		context.fillText(self.opt.proz+"%", x+_x_t , y+_y_t, 130, 20);
		
		if(self.opt.bigLabel) {	
		    context.save(); 
		    context.translate(x, y);		    
		    context.rotate( (3.6*(self.opt.proz/2) )  *Math.PI/180);
		    context.drawImage(self.img,-(self.img.width/2), -(self.img.height/2));
		    context.restore(); 
		}
		context.stroke();
	    }*/
      },
      
      createItems: function() {
	  var self = this;
	  self.currPos = self.startPos;	
	
	  var r=0;
	  var end = null;	  
	  for(var i=self.opt.data.length-1; i > -1; i--) {
	      end = self.currPos + (self.opt.data[i].proz * self.oneProz);  
	      //console.log(self.currPos+' '+end+' | '+self.opt.data[i].proz);
	      var item = new CircleStatus({
		  canvasId: self.opt.canvasId,
		  radius: self.opt.radius,
		  width: 20,
		  start: self.currPos,
		  end: end,
		  color: self.opt.data[i].color,
		  x: self.opt.x,
		  y: self.opt.y,
		  shadow: false,
		  proz: self.opt.data[i].proz,
		  bigLabel: (i==0)? true:false,
		  root: false
	      }); 
	      r+=5;
	      self.items.push(item);
	  }
	  
	  if(self.opt.data.length > 0) {
	      self.currPos =  self.items[self.items.length-1].opt.end;
	      self.animate();
	  }
      }
      
  });
  
})(jQuery);